@@ -10,7 +10,7 @@ use Text::Wrap 'wrap';
 use Bible::OBML::Reference;
 use Bible::OBML::HTML;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 with 'Throwable';
 
@@ -136,7 +136,7 @@ sub parse {
         for (
             [ 'footnote', '[]' ],
             [ 'crossreference', '{}' ],
-            [ 'red text', '<>' ],
+            [ 'red text', '*' ],
             [ 'italic', '^' ],
         ) {
             my $method = ( length( $_->[1] ) == 1 ) ? \&extract_delimited : \&extract_bracketed;
@@ -275,7 +275,7 @@ sub render {
         }
         elsif ( $node->[0] eq 'red text' ) {
             shift @$node;
-            return '<' . join( ' ', map { $render_block->($_) } @$node ) . '>';
+            return '*' . join( ' ', map { $render_block->($_) } @$node ) . '*';
         }
         elsif ( $node->[0] eq 'paragraph' ) {
             return "\n\n";
@@ -486,7 +486,7 @@ Bible::OBML - Open Bible Markup Language parser and renderer
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML)
@@ -532,13 +532,17 @@ following specification:
     =...=    --> header
     {...}    --> crossreferences
     [...]    --> footnotes
-    <...>    --> red text
+    *...*    --> red text
     ^...^    --> italic
     4 spaces --> blockquote (line by line)
     6 spaces --> blockquote + indent (line by line)
-    |*|      --> notes the beginning of a verse (numbers ignored)
+    |*|      --> notes the beginning of a verse (the "*" must be a number)
     #        --> line comments
 
+HTML/XML-like markup can be used throughout the content for additional markup
+not defined by the above specification. When OBML is parsed, such markup
+is ignored and passed through, treated like any other content of the verse.
+
 An example of OBML follows, with several verses missing so as to save space:
 
     ~ Jude 1 ~
@@ -694,6 +698,14 @@ L<Travis CI|https://travis-ci.org/gryphonshafer/Bible-OBML>
 
 L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
 
+=item *
+
+L<CPANTS|http://cpants.cpanauthors.org/dist/Bible-OBML>
+
+=item *
+
+L<CPAN Testers|http://www.cpantesters.org/distro/B/Bible-OBML.html>
+
 =back
 
 =for Pod::Coverage BUILD
