@@ -8,7 +8,7 @@ use Moose;
 use Template;
 use Bible::OBML;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 with 'Throwable';
 
@@ -225,7 +225,7 @@ Bible::OBML::HTML - Render OBML as HTML
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for test_synopsis my( $obml, $filename, $data, $skip_smartify );
 
@@ -329,6 +329,14 @@ L<Travis CI|https://travis-ci.org/gryphonshafer/Bible-OBML>
 
 L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
 
+=item *
+
+L<CPANTS|http://cpants.cpanauthors.org/dist/Bible-OBML>
+
+=item *
+
+L<CPAN Testers|http://www.cpantesters.org/distro/B/Bible-OBML.html>
+
 =back
 
 =head1 AUTHOR
